==> drupal-expay-8.x-1.2.tar.gz: commerce_expay/src/Plugin/Commerce/PaymentGateway/Expay.php <==
<?php

namespace Drupal\expay\Plugin\Commerce\PaymentGateway;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\commerce_payment\PaymentMethodTypeManager;
use Drupal\commerce_payment\PaymentStorageInterface;
use Drupal\commerce_payment\PaymentTypeManager;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayBase;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\SupportsNotificationsInterface;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Url;
use Drupal\expay\Events\ExpayEventHandler;
use Drupal\expay\Provider\ExpayProvider;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides the Expay Checkout payment gateway.
 *
 * @CommercePaymentGateway(
 *   id = "commerce_expay",
 *   label = "Expay",
 *   display_label = "Expay",
 *    forms = {
 *     "offsite-payment" = "Drupal\expay\PluginForm\ExpayForm",
 *   },
 *   payment_method_types = { "expay" },
 * )
 */
class Expay extends OffsitePaymentGatewayBase implements SupportsNotificationsInterface {
  /** @var ExpayEventHandler */
  protected $event_handler;

  /**
   * The payment storage.
   *
   * @var PaymentStorageInterface
   */
  protected $paymentStorage;


  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    PaymentTypeManager $payment_type_manager,
    PaymentMethodTypeManager $payment_method_type_manager,
    TimeInterface $time,
    DateFormatterInterface $date_formatter,
    LanguageManagerInterface $language_manager,
    LoggerChannelFactoryInterface $logger_channel_factory,
    MessengerInterface $messenger,
    ExpayEventHandler $event_handler
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $payment_type_manager,
      $payment_method_type_manager, $time);

    $this->dateFormatter = $date_formatter;
    $this->languageManager = $language_manager;
    $this->logger = $logger_channel_factory->get('commerce_expay');
    $this->messenger = $messenger;
    $this->paymentStorage = $entity_type_manager->getStorage('commerce_payment');
    $this->event_handler = $event_handler;

    if (!defined('EXPAY_PUBLIC_KEY')) {
      define('EXPAY_PUBLIC_KEY', $this->configuration['public_key']);
    }
    if (!defined('EXPAY_SECRET_KEY')) {
      define('EXPAY_PRIVATE_KEY', $this->configuration['private_key']);
    }
    if (!defined('EXPAY_MODE')) {
      define('EXPAY_MODE', $this->configuration['mode']);
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition)
  {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.commerce_payment_type'),
      $container->get('plugin.manager.commerce_payment_method_type'),
      $container->get('datetime.time'),
      $container->get('date.formatter'),
      $container->get('language_manager'),
      $container->get('logger.factory'),
      $container->get('messenger'),
      $container->get('expay_event_handler')
    );
  }

  public function defaultConfiguration()
  {
    return [
        'public_key' => '',
        'private_key' => '',
      ] + parent::defaultConfiguration();
  }

  public function buildConfigurationForm(array $form, FormStateInterface $form_state)
  {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['public_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Expay Public key'),
      '#description' => $this->t('The Public key for the same user as used in Agreement ID.'),
      '#default_value' => $this->configuration['public_key'],
      '#required' => true,
    ];

    $form['private_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Expay Private key'),
      '#description' => $this->t('This is the private key from the Quickpay manager.'),
      '#default_value' => $this->configuration['private_key'],
      '#required' => true,
    ];

    $webhookUrl = $this->getNotifyUrl()->toString();

    $form['webhook_url'] = array(
      '#type' => 'label',
      '#title' => $this->t("Expay Webhook: $webhookUrl ")
    );
    return $form;
  }

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state)
  {
    parent::submitConfigurationForm($form, $form_state);
    $values = $form_state->getValue($form['#parents']);
    $this->configuration['public_key'] = $values['public_key'];
    $this->configuration['private_key'] = $values['private_key'];
  }

  /**
   * {@inheritdoc}
   */
  public function getNotifyUrl() {
    return Url::fromRoute('commerce_payment.notify', [
      'commerce_payment_gateway' => 'expay',
    ], ['absolute' => TRUE]);
  }

  /**
   * {@inheritdoc}
   */
  public function onCancel(OrderInterface $order, Request $request)
  {
    $this->messenger()->addMessage($this->t(
      'You have canceled checkout but may resume the checkout process here when you are ready.'));
  }

  /**
   * {@inheritdoc}
   */
  public function onNotify(Request $request)
  {
    $request_data = $request->request->all();
    if (!isset($request_data, $request_data['data']['merchantOrder'])) {
      return $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
    }
    $payment = $this->paymentStorage->loadByRemoteId($request_data['data']['merchantOrder']);
    if (!isset($payment)) {
      return $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
    }

    return $this->event_handler->handle($request_data, $payment);
  }

  public function sendResponse($code, $message) : JsonResponse {
    $response = [
      'response' => [
        'status' => $code,
        'message' => $message,
        'timestamp' => time()
      ]
    ];
    $response['hash'] = (new ExpayProvider())->hashResponse($response);

    return new JsonResponse($response, $code);
  }
}

==> drupal-expay-8.x-1.6.tar.gz: commerce_expay/src/Plugin/Commerce/PaymentGateway/Expay.php <==
<?php

namespace Drupal\expay\Plugin\Commerce\PaymentGateway;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\commerce_payment\PaymentMethodTypeManager;
use Drupal\commerce_payment\PaymentStorageInterface;
use Drupal\commerce_payment\PaymentTypeManager;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayBase;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\SupportsNotificationsInterface;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Url;
use Drupal\expay\Events\EventHandler;
use Drupal\expay\Provider\Provider;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides the ExPay Checkout payment gateway.
 *
 * @CommercePaymentGateway(
 *   id = "commerce_expay",
 *   label = "ExPay",
 *   display_label = "ExPay",
 *    forms = {
 *     "offsite-payment" = "Drupal\expay\PluginForm\ExpayForm",
 *   },
 *   payment_method_types = { "expay" },
 * )
 */
class Expay extends OffsitePaymentGatewayBase implements SupportsNotificationsInterface {
  /** @var EventHandler */
  protected $event_handler;

  /**
   * The payment storage.
   *
   * @var PaymentStorageInterface
   */
  protected $paymentStorage;


  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    PaymentTypeManager $payment_type_manager,
    PaymentMethodTypeManager $payment_method_type_manager,
    TimeInterface $time,
    DateFormatterInterface $date_formatter,
    LanguageManagerInterface $language_manager,
    LoggerChannelFactoryInterface $logger_channel_factory,
    MessengerInterface $messenger,
    EventHandler $event_handler
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $payment_type_manager,
      $payment_method_type_manager, $time);

    $this->dateFormatter = $date_formatter;
    $this->languageManager = $language_manager;
    $this->logger = $logger_channel_factory->get('commerce_expay');
    $this->messenger = $messenger;
    $this->paymentStorage = $entity_type_manager->getStorage('commerce_payment');
    $this->event_handler = $event_handler;

    if (!defined('PS_PUBLIC_KEY')) {
      define('PS_PUBLIC_KEY', $this->configuration['public_key']);
    }
    if (!defined('PS_PRIVATE_KEY')) {
      define('PS_PRIVATE_KEY', $this->configuration['private_key']);
    }
    if (!defined('PS_MODE')) {
      define('PS_MODE', $this->configuration['mode']);
    }
    if (!defined('PS_LIVE_LINK')) {
      define('PS_LIVE_LINK', $this->configuration['live_link']);
    }
    if (!defined('PS_SANDBOX_LINK')) {
      define('PS_SANDBOX_LINK', $this->configuration['sandbox_link']);
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition)
  {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.commerce_payment_type'),
      $container->get('plugin.manager.commerce_payment_method_type'),
      $container->get('datetime.time'),
      $container->get('date.formatter'),
      $container->get('language_manager'),
      $container->get('logger.factory'),
      $container->get('messenger'),
      $container->get('expay_event_handler')
    );
  }

  public function defaultConfiguration()
  {
    return [
        'public_key' => '',
        'private_key' => '',
        'live_link' => 'https://api.expay.asia/merchant/',
        'sandbox_link' => 'https://api.sandbox.expay.asia/merchant/',
        'webhook_signing_key' => ''
      ] + parent::defaultConfiguration();
  }

  public function buildConfigurationForm(array $form, FormStateInterface $form_state)
  {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['public_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Merchant key'),
      '#description' => $this->t('This is Merchant Public key.'),
      '#default_value' => $this->configuration['public_key'],
      '#required' => true,
    ];

    $form['private_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Merchant secret'),
      '#description' => $this->t('This is Merchant Private key.'),
      '#default_value' => $this->configuration['private_key'],
      '#required' => true,
    ];

    $form['webhook_signing_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Webhook Signing Secret Key'),
      '#description' => $this->t('This is Webhook Signing Secret Key.'),
      '#default_value' => $this->configuration['webhook_signing_key'],
      '#required' => true,
    ];

    $form['live_link'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Live link'),
      '#description' => $this->t('Live link to paysystem API.'),
      '#default_value' => $this->configuration['live_link'],
      '#required' => true,
    ];

    $form['sandbox_link'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Sandbox link'),
      '#description' => $this->t('Sandbox link to paysystem API.'),
      '#default_value' => $this->configuration['sandbox_link'],
      '#required' => true,
    ];

    $webhookUrl = $this->getNotifyUrl()->toString();

    $form['webhook_url'] = array(
      '#type' => 'label',
      '#title' => $this->t("ExPay Webhook: $webhookUrl ")
    );
    return $form;
  }

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state)
  {
    parent::submitConfigurationForm($form, $form_state);
    $values = $form_state->getValue($form['#parents']);
    $this->configuration['public_key'] = $values['public_key'];
    $this->configuration['private_key'] = $values['private_key'];
    $this->configuration['webhook_signing_key'] = $values['webhook_signing_key'];
    $this->configuration['live_link'] = $values['live_link'];
    $this->configuration['sandbox_link'] = $values['sandbox_link'];

  }

  /**
   * {@inheritdoc}
   */
  public function getNotifyUrl() {
    return Url::fromRoute('commerce_payment.notify', [
      'commerce_payment_gateway' => 'expay',
    ], ['absolute' => TRUE]);
  }

  /**
   * {@inheritdoc}
   */
  public function onCancel(OrderInterface $order, Request $request)
  {
    $this->messenger()->addMessage($this->t(
      'You have canceled checkout but may resume the checkout process here when you are ready.'));
  }

  /**
   * {@inheritdoc}
   */
  public function onNotify(Request $request)
  {
    $request_data = $request->request->all();
    if (!isset($request_data, $request_data['data']['merchantOrder'])) {
      return $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
    }
    $payment = $this->paymentStorage->loadByRemoteId($request_data['data']['merchantOrder']);
    if (!isset($payment)) {
      return $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
    }

    return $this->event_handler->handle($request_data, $payment);
  }

  public function sendResponse($code, $message) : JsonResponse {
    $response = [
      'response' => [
        'status' => $code,
        'message' => $message,
        'timestamp' => time()
      ]
    ];
    $response['hash'] = (new Provider())->hashResponse(json_encode($response['response']));

    return new JsonResponse($response, $code);
  }
}
